aboutsummaryrefslogtreecommitdiffstats
path: root/Bootloaders/TeensyHID/TeensyHID.c
diff options
context:
space:
mode:
Diffstat (limited to 'Bootloaders/TeensyHID/TeensyHID.c')
-rw-r--r--Bootloaders/TeensyHID/TeensyHID.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Bootloaders/TeensyHID/TeensyHID.c b/Bootloaders/TeensyHID/TeensyHID.c
index 52526689a..bb5a0c708 100644
--- a/Bootloaders/TeensyHID/TeensyHID.c
+++ b/Bootloaders/TeensyHID/TeensyHID.c
@@ -84,7 +84,7 @@ void SetupHardware(void)
/** Event handler for the USB_ConfigurationChanged event. This configures the device's endpoints ready
* to relay data to and from the attached USB host.
*/
-void EVENT_USB_ConfigurationChanged(void)
+void EVENT_USB_Device_ConfigurationChanged(void)
{
/* Setup HID Report Endpoint */
Endpoint_ConfigureEndpoint(HID_EPNUM, EP_TYPE_INTERRUPT,
@@ -92,11 +92,11 @@ void EVENT_USB_ConfigurationChanged(void)
ENDPOINT_BANK_SINGLE);
}
/** Event handler for the USB_UnhandledControlPacket event. This is used to catch standard and class specific
* control requests that are not handled internally by the USB library (including the HID commands, which are
* all issued via the control endpoint), so that they can be handled appropriately for the application.
*/
-void EVENT_USB_UnhandledControlPacket(void)
+void EVENT_USB_Device_UnhandledControlRequest(void)
{
/* Handle HID Class specific requests */
switch (USB_ControlRequest.bRequest)
@@ -92,11 +92,11 @@ void EVENT_USB_ConfigurationChanged(void)
ENDPOINT_BANK_SINGLE);
}
-/** Event handler for the USB_UnhandledControlPacket event. This is used to catch standard and class specific
+/** Event handler for the USB_UnhandledControlRequest event. This is used to catch standard and class specific
* control requests that are not handled internally by the USB library (including the HID commands, which are
* all issued via the control endpoint), so that they can be handled appropriately for the application.